# astro_pi_orbit

The `astro_pi_orbit` library provides functionality to assist Astro Pi Mission Space Lab participants in working with orbital data.

Documentation is available at [docs](./docs).

## Contributing

We welcome all contributions!
Please install and run the dependencies in `requirements-dev.txt`, and run `pre-commit` prior to opening a PR. On Unix, `pre-commit` can be installed by running the following:

```bash
pip install pre-commit
pre-commit install
```

